@@ -3,6 +3,7 @@ from starlette.requests import Request
 class Middleware:
     def __init__(self, app):
         self.app = app
+        self.test = "YAY"
     
     async def __call__(self, scope, receive, send):
         request = Request(scope=scope, receive=receive)
@@ -10,6 +11,7 @@ class Middleware:
         response = self.app.handle_request(request)
         
         await response(scope, receive, send)
+        return response(scope, receive, send)
 
     def add(self, middleware_cls):
         self.app = middleware_cls(self.app)
